require 'usaepay.rb'
require 'usaepayMappingRegistry.rb'
require 'soap/rpc/driver'

class UeSoapServerPortType < ::SOAP::RPC::Driver
  DefaultEndpointUrl = "https://www.usaepay.com/soap/gate/DFBAABC3"
  NsUsaepay = "urn:usaepay"

  Methods = [
    [ XSD::QName.new(NsUsaepay, "addCustomer"),
      "urn:ueSoapServerAction",
      "addCustomer",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustomerData", ["CustomerObject", "urn:usaepay", "CustomerObject"]],
        ["retval", "addCustomerReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "addCustomerPaymentMethod"),
      "urn:ueSoapServerAction",
      "addCustomerPaymentMethod",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["in", "PaymentMethod", ["PaymentMethod", "urn:usaepay", "PaymentMethod"]],
        ["in", "MakeDefault", ["::SOAP::SOAPBoolean"]],
        ["in", "Verify", ["::SOAP::SOAPBoolean"]],
        ["retval", "addCustomerPaymentMethodReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "addProduct"),
      "urn:ueSoapServerAction",
      "addProduct",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Product", ["Product", "urn:usaepay", "Product"]],
        ["retval", "ProductRefNum", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "addProductCategory"),
      "urn:ueSoapServerAction",
      "addProductCategory",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductCategory", ["ProductCategory", "urn:usaepay", "ProductCategory"]],
        ["retval", "ProductCategoryRefNum", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "addReceipt"),
      "urn:ueSoapServerAction",
      "addReceipt",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Receipt", ["Receipt", "urn:usaepay", "Receipt"]],
        ["retval", "addReceiptResponseReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "adjustInventory"),
      "urn:ueSoapServerAction",
      "adjustInventory",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductRefNum", ["::SOAP::SOAPString"]],
        ["in", "Inventory", ["ProductInventoryArray", "urn:usaepay", "ProductInventoryArray"]],
        ["retval", "adjustInventoryReturn", ["ProductInventoryArray", "urn:usaepay", "ProductInventoryArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "bulkCurrencyConversion"),
      "urn:ueSoapServerAction",
      "bulkCurrencyConversion",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "FromCurrency", ["::SOAP::SOAPString"]],
        ["in", "ToCurrency", ["::SOAP::SOAPString"]],
        ["in", "Amounts", ["DoubleArray", "urn:usaepay", "doubleArray"]],
        ["retval", "bulkCurrencyConversionReturn", ["CurrencyConversionArray", "urn:usaepay", "CurrencyConversionArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "captureTransaction"),
      "urn:ueSoapServerAction",
      "captureTransaction",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "Amount", ["::SOAP::SOAPDouble"]],
        ["retval", "captureTransactionReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "closeBatch"),
      "urn:ueSoapServerAction",
      "closeBatch",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "BatchRefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "closeBatchReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "convertTranToCust"),
      "urn:ueSoapServerAction",
      "convertTranToCust",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "UpdateData", ["FieldValueArray", "urn:usaepay", "FieldValueArray"]],
        ["retval", "convertTranToCustReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "copyCustomer"),
      "urn:ueSoapServerAction",
      "copyCustomer",
      [ ["in", "CopyFromToken", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["in", "CopyToToken", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["retval", "copyCustomerReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "createBatchUpload"),
      "urn:ueSoapServerAction",
      "createBatchUpload",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "FileName", ["::SOAP::SOAPString"]],
        ["in", "AutoStart", ["::SOAP::SOAPBoolean"]],
        ["in", "Format", ["::SOAP::SOAPString"]],
        ["in", "Encoding", ["::SOAP::SOAPString"]],
        ["in", "Fields", ["StringArray", "urn:usaepay", "stringArray"]],
        ["in", "Data", ["::SOAP::SOAPString"]],
        ["in", "OverrideDuplicates", ["::SOAP::SOAPBoolean"]],
        ["retval", "createBatchUploadReturn", ["BatchUploadStatus", "urn:usaepay", "BatchUploadStatus"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "currencyConversion"),
      "urn:ueSoapServerAction",
      "currencyConversion",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "FromCurrency", ["::SOAP::SOAPString"]],
        ["in", "ToCurrency", ["::SOAP::SOAPString"]],
        ["in", "Amount", ["::SOAP::SOAPDouble"]],
        ["retval", "currencyConversionReturn", ["CurrencyConversion", "urn:usaepay", "CurrencyConversion"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "deleteCustomer"),
      "urn:ueSoapServerAction",
      "deleteCustomer",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["retval", "deleteCustomerReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "deleteCustomerPaymentMethod"),
      "urn:ueSoapServerAction",
      "deleteCustomerPaymentMethod",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Custnum", ["::SOAP::SOAPInteger"]],
        ["in", "PaymentMethodID", ["::SOAP::SOAPInteger"]],
        ["retval", "deleteCustomerPaymentMethodReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "deleteProduct"),
      "urn:ueSoapServerAction",
      "deleteProduct",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductRefNum", ["::SOAP::SOAPString"]],
        ["retval", "deleteProductReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "deleteProductCategory"),
      "urn:ueSoapServerAction",
      "deleteProductCategory",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductCategoryRefNum", ["::SOAP::SOAPString"]],
        ["retval", "deleteProductCategoryReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "deleteReceipt"),
      "urn:ueSoapServerAction",
      "deleteReceipt",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ReceiptRefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "deleteReceiptReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "disableCustomer"),
      "urn:ueSoapServerAction",
      "disableCustomer",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["retval", "disableCustomerReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "enableCustomer"),
      "urn:ueSoapServerAction",
      "enableCustomer",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["retval", "enableCustomerReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "emailTransactionReceipt"),
      "urn:ueSoapServerAction",
      "emailTransactionReceipt",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "ReceiptRefNum", ["::SOAP::SOAPInteger"]],
        ["in", "Email", ["::SOAP::SOAPString"]],
        ["retval", "emailTransactionReceiptReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "emailTransactionReceiptByName"),
      "urn:ueSoapServerAction",
      "emailTransactionReceiptByName",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "ReceiptName", ["::SOAP::SOAPString"]],
        ["in", "Email", ["::SOAP::SOAPString"]],
        ["retval", "emailTransactionReceiptByNameReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getAccountDetails"),
      "urn:ueSoapServerAction",
      "getAccountDetails",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["retval", "getAccountDetailsReturn", ["AccountDetails", "urn:usaepay", "AccountDetails"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getBankList"),
      "urn:ueSoapServerAction",
      "getBankList",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["retval", "getBankListDetailsReturn", ["BankArray", "urn:usaepay", "BankArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getBatchStatus"),
      "urn:ueSoapServerAction",
      "getBatchStatus",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "BatchRefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getBatchStatusReturn", ["BatchStatus", "urn:usaepay", "BatchStatus"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getBatchTransactions"),
      "urn:ueSoapServerAction",
      "getBatchTransactions",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "BatchRefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getBatchTransactionsReturn", ["TransactionObjectArray", "urn:usaepay", "TransactionObjectArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getBatchUploadStatus"),
      "urn:ueSoapServerAction",
      "getBatchUploadStatus",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "UploadRefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getBatchUploadStatusReturn", ["BatchUploadStatus", "urn:usaepay", "BatchUploadStatus"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getCheckTrace"),
      "urn:ueSoapServerAction",
      "getCheckTrace",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getCheckTraceReturn", ["CheckTrace", "urn:usaepay", "CheckTrace"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getCustomer"),
      "urn:ueSoapServerAction",
      "getCustomer",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getCustomerReturn", ["CustomerObject", "urn:usaepay", "CustomerObject"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getCustomerHistory"),
      "urn:ueSoapServerAction",
      "getCustomerHistory",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getCustomerHistoryReturn", ["TransactionSearchResult", "urn:usaepay", "TransactionSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getCustomerPaymentMethod"),
      "urn:ueSoapServerAction",
      "getCustomerPaymentMethod",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["in", "MethodID", ["::SOAP::SOAPInteger"]],
        ["retval", "getCustomerPaymentMethodReturn", ["PaymentMethod", "urn:usaepay", "PaymentMethod"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getCustomerPaymentMethods"),
      "urn:ueSoapServerAction",
      "getCustomerPaymentMethods",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getCustomerPaymentMethodsReturn", ["PaymentMethodArray", "urn:usaepay", "PaymentMethodArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getCustomerReport"),
      "urn:ueSoapServerAction",
      "getCustomerReport",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Report", ["::SOAP::SOAPString"]],
        ["in", "Options", ["FieldValueArray", "urn:usaepay", "FieldValueArray"]],
        ["in", "Format", ["::SOAP::SOAPString"]],
        ["retval", "getCustomerReportReturn", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getCustomFields"),
      "urn:ueSoapServerAction",
      "getCustomFields",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["retval", "getCustomFieldsReturn", ["FieldValueArray", "urn:usaepay", "FieldValueArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getProduct"),
      "urn:ueSoapServerAction",
      "getProduct",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductRefNum", ["::SOAP::SOAPString"]],
        ["retval", "getProductReturn", ["Product", "urn:usaepay", "Product"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getProductCategory"),
      "urn:ueSoapServerAction",
      "getProductCategory",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductCategoryRefNum", ["::SOAP::SOAPString"]],
        ["retval", "getProductCategoryReturn", ["ProductCategory", "urn:usaepay", "ProductCategory"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getProductCategories"),
      "urn:ueSoapServerAction",
      "getProductCategories",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["retval", "getProductCategoriesReturn", ["ProductCategoryArray", "urn:usaepay", "ProductCategoryArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getProductInventory"),
      "urn:ueSoapServerAction",
      "getProductInventory",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductRefNum", ["::SOAP::SOAPString"]],
        ["retval", "getProductInventoryReturn", ["ProductInventoryArray", "urn:usaepay", "ProductInventoryArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getReceipt"),
      "urn:ueSoapServerAction",
      "getReceipt",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ReceiptRefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getReceiptReturn", ["Receipt", "urn:usaepay", "Receipt"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getReceiptByName"),
      "urn:ueSoapServerAction",
      "getReceiptByName",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Name", ["::SOAP::SOAPString"]],
        ["retval", "getReceiptByNameReturn", ["Receipt", "urn:usaepay", "Receipt"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getReceipts"),
      "urn:ueSoapServerAction",
      "getReceipts",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Target", ["::SOAP::SOAPString"]],
        ["retval", "getReceiptsReturn", ["ReceiptArray", "urn:usaepay", "ReceiptArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getReport"),
      "urn:ueSoapServerAction",
      "getReport",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Report", ["::SOAP::SOAPString"]],
        ["in", "Options", ["FieldValueArray", "urn:usaepay", "FieldValueArray"]],
        ["in", "Format", ["::SOAP::SOAPString"]],
        ["retval", "getReportReturn", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getSupportedCurrencies"),
      "urn:ueSoapServerAction",
      "getSupportedCurrencies",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["retval", "getSupportedCurrenciesReturn", ["CurrencyObjectArray", "urn:usaepay", "CurrencyObjectArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getSyncLog"),
      "urn:ueSoapServerAction",
      "getSyncLog",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ObjectName", ["::SOAP::SOAPString"]],
        ["in", "FromPosition", ["::SOAP::SOAPInteger"]],
        ["retval", "getSyncLogReturn", ["SyncLogArray", "urn:usaepay", "SyncLogArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getSyncLogCurrentPosition"),
      "urn:ueSoapServerAction",
      "getSyncLogCurrentPosition",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ObjectName", ["::SOAP::SOAPString"]],
        ["retval", "getSyncLogCurrentPositionReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getSystemInfo"),
      "urn:ueSoapServerAction",
      "getSystemInfo",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["retval", "getSystemInfoReturn", ["SystemInfo", "urn:usaepay", "SystemInfo"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getTransaction"),
      "urn:ueSoapServerAction",
      "getTransaction",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getTransactionReturn", ["TransactionObject", "urn:usaepay", "TransactionObject"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getTransactionCustom"),
      "urn:ueSoapServerAction",
      "getTransactionCustom",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "Fields", ["StringArray", "urn:usaepay", "stringArray"]],
        ["retval", "getTransactionCustomReturn", ["FieldValueArray", "urn:usaepay", "FieldValueArray"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getTransactionReport"),
      "urn:ueSoapServerAction",
      "getTransactionReport",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "StartDate", ["::SOAP::SOAPString"]],
        ["in", "EndDate", ["::SOAP::SOAPString"]],
        ["in", "Report", ["::SOAP::SOAPString"]],
        ["in", "Format", ["::SOAP::SOAPString"]],
        ["retval", "getTransactionReportReturn", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "getTransactionStatus"),
      "urn:ueSoapServerAction",
      "getTransactionStatus",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "getTransactionStatusReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "moveCustomer"),
      "urn:ueSoapServerAction",
      "moveCustomer",
      [ ["in", "MoveFromToken", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["in", "MoveToToken", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["retval", "moveCustomerReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "pauseBatchUpload"),
      "urn:ueSoapServerAction",
      "pauseBatchUpload",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "UploadRefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "pauseBatchUploadReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "postAuth"),
      "urn:ueSoapServerAction",
      "postAuth",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Params", ["TransactionRequestObject", "urn:usaepay", "TransactionRequestObject"]],
        ["retval", "postAuthReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "quickUpdateCustomer"),
      "urn:ueSoapServerAction",
      "quickUpdateCustomer",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["in", "UpdateData", ["FieldValueArray", "urn:usaepay", "FieldValueArray"]],
        ["retval", "quickUpdateCustomerReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "quickUpdateProduct"),
      "urn:ueSoapServerAction",
      "quickUpdateProduct",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductRefNum", ["::SOAP::SOAPString"]],
        ["in", "UpdateData", ["FieldValueArray", "urn:usaepay", "FieldValueArray"]],
        ["retval", "quickUpdateProductReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "refundTransaction"),
      "urn:ueSoapServerAction",
      "refundTransaction",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "Amount", ["::SOAP::SOAPDouble"]],
        ["retval", "refundTransactionReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "renderReceipt"),
      "urn:ueSoapServerAction",
      "renderReceipt",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "ReceiptRefNum", ["::SOAP::SOAPInteger"]],
        ["in", "ContentType", ["::SOAP::SOAPString"]],
        ["retval", "renderReceiptReturn", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "renderReceiptByName"),
      "urn:ueSoapServerAction",
      "renderReceiptByName",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "ReceiptName", ["::SOAP::SOAPString"]],
        ["in", "ContentType", ["::SOAP::SOAPString"]],
        ["retval", "renderReceiptByNameReturn", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runBatchUpload"),
      "urn:ueSoapServerAction",
      "runBatchUpload",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "UploadRefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "runBatchUploadReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runCredit"),
      "urn:ueSoapServerAction",
      "runCredit",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Params", ["TransactionRequestObject", "urn:usaepay", "TransactionRequestObject"]],
        ["retval", "runCreditReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runCheckCredit"),
      "urn:ueSoapServerAction",
      "runCheckCredit",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Params", ["TransactionRequestObject", "urn:usaepay", "TransactionRequestObject"]],
        ["retval", "runCheckCreditReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runCustomerTransaction"),
      "urn:ueSoapServerAction",
      "runCustomerTransaction",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["in", "PaymentMethodID", ["::SOAP::SOAPInteger"]],
        ["in", "Parameters", ["CustomerTransactionRequest", "urn:usaepay", "CustomerTransactionRequest"]],
        ["retval", "runCustomerTransactionReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runQuickSale"),
      "urn:ueSoapServerAction",
      "runQuickSale",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "Details", ["TransactionDetail", "urn:usaepay", "TransactionDetail"]],
        ["in", "AuthOnly", ["::SOAP::SOAPBoolean"]],
        ["retval", "runQuickSaleReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runQuickCredit"),
      "urn:ueSoapServerAction",
      "runQuickCredit",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "Details", ["TransactionDetail", "urn:usaepay", "TransactionDetail"]],
        ["retval", "runQuickCreditReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runCheckSale"),
      "urn:ueSoapServerAction",
      "runCheckSale",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Params", ["TransactionRequestObject", "urn:usaepay", "TransactionRequestObject"]],
        ["retval", "runCheckSaleReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runSale"),
      "urn:ueSoapServerAction",
      "runSale",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Params", ["TransactionRequestObject", "urn:usaepay", "TransactionRequestObject"]],
        ["retval", "runSaleReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runAuthOnly"),
      "urn:ueSoapServerAction",
      "runAuthOnly",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Params", ["TransactionRequestObject", "urn:usaepay", "TransactionRequestObject"]],
        ["retval", "runAuthOnlyReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runTransaction"),
      "urn:ueSoapServerAction",
      "runTransaction",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Parameters", ["TransactionRequestObject", "urn:usaepay", "TransactionRequestObject"]],
        ["retval", "runTransactionReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "runTransactionAPI"),
      "urn:ueSoapServerAction",
      "runTransactionAPI",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Parameters", ["FieldValueArray", "urn:usaepay", "FieldValueArray"]],
        ["retval", "runTransactionAPIReturn", ["TransactionResponse", "urn:usaepay", "TransactionResponse"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchBatches"),
      "urn:ueSoapServerAction",
      "searchBatches",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchBatchesReturn", ["BatchSearchResult", "urn:usaepay", "BatchSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchBatchesCount"),
      "urn:ueSoapServerAction",
      "searchBatchesCount",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchBatchesCountReturn", ["BatchSearchResult", "urn:usaepay", "BatchSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchCustomerID"),
      "urn:ueSoapServerAction",
      "searchCustomerID",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustID", ["::SOAP::SOAPString"]],
        ["retval", "searchCustomerIDReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchCustomers"),
      "urn:ueSoapServerAction",
      "searchCustomers",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchCustomersReturn", ["CustomerSearchResult", "urn:usaepay", "CustomerSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchCustomersCount"),
      "urn:ueSoapServerAction",
      "searchCustomersCount",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchCustomersCountReturn", ["CustomerSearchResult", "urn:usaepay", "CustomerSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchCustomersCustom"),
      "urn:ueSoapServerAction",
      "searchCustomersCustom",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "FieldList", ["StringArray", "urn:usaepay", "stringArray"]],
        ["in", "Format", ["::SOAP::SOAPString"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchCustomersCustomReturn", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchProducts"),
      "urn:ueSoapServerAction",
      "searchProducts",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchProductsReturn", ["ProductSearchResult", "urn:usaepay", "ProductSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchProductsCount"),
      "urn:ueSoapServerAction",
      "searchProductsCount",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchProductsCountReturn", ["ProductSearchResult", "urn:usaepay", "ProductSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchProductsCustom"),
      "urn:ueSoapServerAction",
      "searchProductsCustom",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "FieldList", ["StringArray", "urn:usaepay", "stringArray"]],
        ["in", "Format", ["::SOAP::SOAPString"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchProductsCustomReturn", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchTransactions"),
      "urn:ueSoapServerAction",
      "searchTransactions",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchTransactionsReturn", ["TransactionSearchResult", "urn:usaepay", "TransactionSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchTransactionsCount"),
      "urn:ueSoapServerAction",
      "searchTransactionsCount",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchTransactionsCountReturn", ["TransactionSearchResult", "urn:usaepay", "TransactionSearchResult"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "searchTransactionsCustom"),
      "urn:ueSoapServerAction",
      "searchTransactionsCustom",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "Search", ["SearchParamArray", "urn:usaepay", "SearchParamArray"]],
        ["in", "MatchAll", ["::SOAP::SOAPBoolean"]],
        ["in", "Start", ["::SOAP::SOAPInteger"]],
        ["in", "Limit", ["::SOAP::SOAPInteger"]],
        ["in", "FieldList", ["StringArray", "urn:usaepay", "stringArray"]],
        ["in", "Format", ["::SOAP::SOAPString"]],
        ["in", "Sort", ["::SOAP::SOAPString"]],
        ["retval", "searchTransactionsCustomReturn", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "updateCustomer"),
      "urn:ueSoapServerAction",
      "updateCustomer",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "CustNum", ["::SOAP::SOAPInteger"]],
        ["in", "CustomerData", ["CustomerObject", "urn:usaepay", "CustomerObject"]],
        ["retval", "updateCustomerReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "updateCustomerPaymentMethod"),
      "urn:ueSoapServerAction",
      "updateCustomerPaymentMethod",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "PaymentMethod", ["PaymentMethod", "urn:usaepay", "PaymentMethod"]],
        ["in", "Verify", ["::SOAP::SOAPBoolean"]],
        ["retval", "updateCustomerPaymentMethodReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "updateProduct"),
      "urn:ueSoapServerAction",
      "updateProduct",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductRefNum", ["::SOAP::SOAPString"]],
        ["in", "Product", ["Product", "urn:usaepay", "Product"]],
        ["retval", "updateProductReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "updateProductCategory"),
      "urn:ueSoapServerAction",
      "updateProductCategory",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ProductCategoryRefNum", ["::SOAP::SOAPString"]],
        ["in", "ProductCategory", ["ProductCategory", "urn:usaepay", "ProductCategory"]],
        ["retval", "updateProductCategoryReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "updateReceipt"),
      "urn:ueSoapServerAction",
      "updateReceipt",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "ReceiptRefNum", ["::SOAP::SOAPInteger"]],
        ["in", "Receipt", ["Receipt", "urn:usaepay", "Receipt"]],
        ["retval", "updateReceiptResponseReturn", ["::SOAP::SOAPInteger"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "voidTransaction"),
      "urn:ueSoapServerAction",
      "voidTransaction",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["retval", "voidTransactionReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsUsaepay, "overrideTransaction"),
      "urn:ueSoapServerAction",
      "overrideTransaction",
      [ ["in", "Token", ["UeSecurityToken", "urn:usaepay", "ueSecurityToken"]],
        ["in", "RefNum", ["::SOAP::SOAPInteger"]],
        ["in", "Reason", ["::SOAP::SOAPString"]],
        ["retval", "overrideTransactionReturn", ["::SOAP::SOAPBoolean"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ]
  ]

  def initialize(endpoint_url = nil)
    endpoint_url ||= DefaultEndpointUrl
    super(endpoint_url, nil)
    self.mapping_registry = UsaepayMappingRegistry::EncodedRegistry
    self.literal_mapping_registry = UsaepayMappingRegistry::LiteralRegistry
    init_methods
  end

private

  def init_methods
    Methods.each do |definitions|
      opt = definitions.last
      if opt[:request_style] == :document
        add_document_operation(*definitions)
      else
        add_rpc_operation(*definitions)
        qname = definitions[0]
        name = definitions[2]
        if qname.name != name and qname.name.capitalize == name.capitalize
          ::SOAP::Mapping.define_singleton_method(self, qname.name) do |*arg|
            __send__(name, *arg)
          end
        end
      end
    end
  end
end

